@@ -2,7 +2,7 @@ package Cairo::Install::Files;
 
 $self = {
           'deps' => [],
-          'inc' => '-I. -Ibuild -I/usr/include/cairo -I/usr/include/glib-2.0 -I/usr/lib/glib-2.0/include -I/usr/lib/libffi-3.2.1/include -I/usr/include/pixman-1 -I/usr/include/freetype2 -I/usr/include/libpng16 -I/usr/include/harfbuzz  -I/usr/include/cairo -I/usr/include/glib-2.0 -I/usr/lib/glib-2.0/include -I/usr/lib/libffi-3.2.1/include -I/usr/include/pixman-1 -I/usr/include/freetype2 -I/usr/include/libpng16 -I/usr/include/harfbuzz ',
+          'inc' => '-I. -Ibuild -I/usr/include/cairo -I/usr/include/lzo -I/usr/include/libpng16 -I/usr/include/freetype2 -I/usr/include/harfbuzz -I/usr/include/glib-2.0 -I/usr/lib/glib-2.0/include -I/usr/include/pixman-1  -I/usr/include/cairo -I/usr/include/lzo -I/usr/include/libpng16 -I/usr/include/freetype2 -I/usr/include/harfbuzz -I/usr/include/glib-2.0 -I/usr/lib/glib-2.0/include -I/usr/include/pixman-1 ',
           'libs' => '-lcairo  -lcairo -lfreetype ',
           'typemaps' => [
                           'cairo-perl-auto.typemap',
@@ -27,11 +27,6 @@ $inc = $self->{inc};
 
 	sub Inline {
 		my ($class, $lang) = @_;
-		if ($lang ne 'C') {
-			warn "Warning: Inline hints not available for $lang language
-";
-			return;
-		}
 		+{ map { (uc($_) => $self->{$_}) } qw(inc libs typemaps) };
 	}
 
